#
# spec file for package orthanc-postgresql
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2023 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-postgresql
Summary:        Database plugin for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Databases/Tools
Version:        5.1
Release:        1.7
URL:            https://orthanc-server.com
Source0:        https://www.orthanc-server.com/downloads/get.php?path=/plugin-postgresql/OrthancPostgreSQL-%{version}.tar.gz
Source1:        orthanc-postgresql-readme.SUSE
Source2:        postgresql.json
BuildRequires:  cmake
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc-c++
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_atomic-devel >= 1.66
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  postgresql-devel
BuildRequires:  protobuf-devel
#TW/Leap 15.2
%if 0%{?sle_version} > 150100 || 0%{?suse_version} > 1500
BuildRequires:  postgresql-server-devel
%endif
BuildRequires:  unzip
BuildRequires:  uuid-devel
BuildRequires:  zlib-devel

Requires:       orthanc
Requires:       postgresql-server

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
PostgreSQL Database plugin for Orthanc, replaces SQLite database

%prep

%setup -q -n OrthancPostgresql-%{version}

%build

%cmake ../PostgreSQL \
       -DALLOW_DOWNLOADS=ON \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install

mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancPostgreSQLIndex.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancPostgreSQLIndex.so

ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancPostgreSQLStorage.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancPostgreSQLStorage.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{S:1} %{S:2} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Tue Jul 11 2023 Axel Braun <axel.braun@gmx.de>
- version 5.1
  * Optimization of LookupResources mainly used in tools/find, C-Find and QIDO-RS.
- version 5.0
  * Compatibility with Orthanc SDK 1.12.0 (communications between the
    Orthanc core and the database plugin using Google Protocol Buffers)
  * Upgraded dependencies for static builds (notably on Windows and LSB):
  - openssl 3.1.0
  * psql114.patch removed (included in source)
* Sun May  9 2021 Axel Braun <axel.braun@gmx.de>
- Version 4.0 (no changelog)
* Mon Dec 14 2020 Axel Braun <axel.braun@gmx.de>
- Version 3.3
  * Added an advisory lock to avoid race conditions during database setup
  * Added "MaximumConnectionRetries" & "ConnectionRetryInterval" to configure
  the retries when connecting to the DB at startup
  * Support of dynamic linking against the system-wide Orthanc framework library
  * build aginst orthanc-framework removed
* Thu Oct 22 2020 Axel Braun <axel.braun@gmx.de>
- switch to orthanc-framework (static version)
  psql114.patch extended for psql 12/13 versions
* Sun Mar 15 2020 Max Lin <mlin@suse.com>
- For Leap version >= 15.2, postgresql-server-devel need to be used
* Mon Aug  5 2019 Axel Braun <axel.braun@gmx.de>
- Version 3.2
  Initial build on OBS
